@@ -1,9 +1,11 @@
 from brownie.convert.datatypes import (
     Wei,
-    EthAddress as Address
+    EthAddress as Address,
+    HexString
 )
 
 __all__ = [
     "Wei",
     "Address",
+    "HexString",
 ]
